# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/cloud/talent_v4beta1/proto/completion_service.proto

import sys

_b = sys.version_info[0] < 3 and (lambda x: x) or (lambda x: x.encode("latin1"))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2
from google.api import resource_pb2 as google_dot_api_dot_resource__pb2
from google.cloud.talent_v4beta1.proto import (
    common_pb2 as google_dot_cloud_dot_talent__v4beta1_dot_proto_dot_common__pb2,
)
from google.api import client_pb2 as google_dot_api_dot_client__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
    name="google/cloud/talent_v4beta1/proto/completion_service.proto",
    package="google.cloud.talent.v4beta1",
    syntax="proto3",
    serialized_options=_b(
        "\n\037com.google.cloud.talent.v4beta1B\026CompletionServiceProtoP\001ZAgoogle.golang.org/genproto/googleapis/cloud/talent/v4beta1;talent\242\002\003CTS"
    ),
    serialized_pb=_b(
        '\n:google/cloud/talent_v4beta1/proto/completion_service.proto\x12\x1bgoogle.cloud.talent.v4beta1\x1a\x1cgoogle/api/annotations.proto\x1a\x1fgoogle/api/field_behavior.proto\x1a\x19google/api/resource.proto\x1a.google/cloud/talent_v4beta1/proto/common.proto\x1a\x17google/api/client.proto"\x9b\x04\n\x14\x43ompleteQueryRequest\x12;\n\x06parent\x18\x01 \x01(\tB+\xe0\x41\x02\xfa\x41%\n#jobs.googleapis.com/TenantOrProject\x12\x12\n\x05query\x18\x02 \x01(\tB\x03\xe0\x41\x02\x12\x16\n\x0elanguage_codes\x18\x03 \x03(\t\x12\x16\n\tpage_size\x18\x04 \x01(\x05\x42\x03\xe0\x41\x02\x12\x31\n\x07\x63ompany\x18\x05 \x01(\tB \xfa\x41\x1d\n\x1bjobs.googleapis.com/Company\x12P\n\x05scope\x18\x06 \x01(\x0e\x32\x41.google.cloud.talent.v4beta1.CompleteQueryRequest.CompletionScope\x12N\n\x04type\x18\x07 \x01(\x0e\x32@.google.cloud.talent.v4beta1.CompleteQueryRequest.CompletionType"K\n\x0f\x43ompletionScope\x12 \n\x1c\x43OMPLETION_SCOPE_UNSPECIFIED\x10\x00\x12\n\n\x06TENANT\x10\x01\x12\n\n\x06PUBLIC\x10\x02"`\n\x0e\x43ompletionType\x12\x1f\n\x1b\x43OMPLETION_TYPE_UNSPECIFIED\x10\x00\x12\r\n\tJOB_TITLE\x10\x01\x12\x10\n\x0c\x43OMPANY_NAME\x10\x02\x12\x0c\n\x08\x43OMBINED\x10\x03"\xc5\x02\n\x15\x43ompleteQueryResponse\x12_\n\x12\x63ompletion_results\x18\x01 \x03(\x0b\x32\x43.google.cloud.talent.v4beta1.CompleteQueryResponse.CompletionResult\x12?\n\x08metadata\x18\x02 \x01(\x0b\x32-.google.cloud.talent.v4beta1.ResponseMetadata\x1a\x89\x01\n\x10\x43ompletionResult\x12\x12\n\nsuggestion\x18\x01 \x01(\t\x12N\n\x04type\x18\x02 \x01(\x0e\x32@.google.cloud.talent.v4beta1.CompleteQueryRequest.CompletionType\x12\x11\n\timage_uri\x18\x03 \x01(\t2\xd5\x02\n\nCompletion\x12\xd8\x01\n\rCompleteQuery\x12\x31.google.cloud.talent.v4beta1.CompleteQueryRequest\x1a\x32.google.cloud.talent.v4beta1.CompleteQueryResponse"`\x82\xd3\xe4\x93\x02Z\x12//v4beta1/{parent=projects/*/tenants/*}:completeZ\'\x12%/v4beta1/{parent=projects/*}:complete\x1al\xca\x41\x13jobs.googleapis.com\xd2\x41Shttps://www.googleapis.com/auth/cloud-platform,https://www.googleapis.com/auth/jobsB\x84\x01\n\x1f\x63om.google.cloud.talent.v4beta1B\x16\x43ompletionServiceProtoP\x01ZAgoogle.golang.org/genproto/googleapis/cloud/talent/v4beta1;talent\xa2\x02\x03\x43TSb\x06proto3'
    ),
    dependencies=[
        google_dot_api_dot_annotations__pb2.DESCRIPTOR,
        google_dot_api_dot_field__behavior__pb2.DESCRIPTOR,
        google_dot_api_dot_resource__pb2.DESCRIPTOR,
        google_dot_cloud_dot_talent__v4beta1_dot_proto_dot_common__pb2.DESCRIPTOR,
        google_dot_api_dot_client__pb2.DESCRIPTOR,
    ],
)


_COMPLETEQUERYREQUEST_COMPLETIONSCOPE = _descriptor.EnumDescriptor(
    name="CompletionScope",
    full_name="google.cloud.talent.v4beta1.CompleteQueryRequest.CompletionScope",
    filename=None,
    file=DESCRIPTOR,
    values=[
        _descriptor.EnumValueDescriptor(
            name="COMPLETION_SCOPE_UNSPECIFIED",
            index=0,
            number=0,
            serialized_options=None,
            type=None,
        ),
        _descriptor.EnumValueDescriptor(
            name="TENANT", index=1, number=1, serialized_options=None, type=None
        ),
        _descriptor.EnumValueDescriptor(
            name="PUBLIC", index=2, number=2, serialized_options=None, type=None
        ),
    ],
    containing_type=None,
    serialized_options=None,
    serialized_start=621,
    serialized_end=696,
)
_sym_db.RegisterEnumDescriptor(_COMPLETEQUERYREQUEST_COMPLETIONSCOPE)

_COMPLETEQUERYREQUEST_COMPLETIONTYPE = _descriptor.EnumDescriptor(
    name="CompletionType",
    full_name="google.cloud.talent.v4beta1.CompleteQueryRequest.CompletionType",
    filename=None,
    file=DESCRIPTOR,
    values=[
        _descriptor.EnumValueDescriptor(
            name="COMPLETION_TYPE_UNSPECIFIED",
            index=0,
            number=0,
            serialized_options=None,
            type=None,
        ),
        _descriptor.EnumValueDescriptor(
            name="JOB_TITLE", index=1, number=1, serialized_options=None, type=None
        ),
        _descriptor.EnumValueDescriptor(
            name="COMPANY_NAME", index=2, number=2, serialized_options=None, type=None
        ),
        _descriptor.EnumValueDescriptor(
            name="COMBINED", index=3, number=3, serialized_options=None, type=None
        ),
    ],
    containing_type=None,
    serialized_options=None,
    serialized_start=698,
    serialized_end=794,
)
_sym_db.RegisterEnumDescriptor(_COMPLETEQUERYREQUEST_COMPLETIONTYPE)


_COMPLETEQUERYREQUEST = _descriptor.Descriptor(
    name="CompleteQueryRequest",
    full_name="google.cloud.talent.v4beta1.CompleteQueryRequest",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="parent",
            full_name="google.cloud.talent.v4beta1.CompleteQueryRequest.parent",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=_b(
                "\340A\002\372A%\n#jobs.googleapis.com/TenantOrProject"
            ),
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="query",
            full_name="google.cloud.talent.v4beta1.CompleteQueryRequest.query",
            index=1,
            number=2,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=_b("\340A\002"),
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="language_codes",
            full_name="google.cloud.talent.v4beta1.CompleteQueryRequest.language_codes",
            index=2,
            number=3,
            type=9,
            cpp_type=9,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="page_size",
            full_name="google.cloud.talent.v4beta1.CompleteQueryRequest.page_size",
            index=3,
            number=4,
            type=5,
            cpp_type=1,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=_b("\340A\002"),
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="company",
            full_name="google.cloud.talent.v4beta1.CompleteQueryRequest.company",
            index=4,
            number=5,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=_b("\372A\035\n\033jobs.googleapis.com/Company"),
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="scope",
            full_name="google.cloud.talent.v4beta1.CompleteQueryRequest.scope",
            index=5,
            number=6,
            type=14,
            cpp_type=8,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="type",
            full_name="google.cloud.talent.v4beta1.CompleteQueryRequest.type",
            index=6,
            number=7,
            type=14,
            cpp_type=8,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[
        _COMPLETEQUERYREQUEST_COMPLETIONSCOPE,
        _COMPLETEQUERYREQUEST_COMPLETIONTYPE,
    ],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=255,
    serialized_end=794,
)


_COMPLETEQUERYRESPONSE_COMPLETIONRESULT = _descriptor.Descriptor(
    name="CompletionResult",
    full_name="google.cloud.talent.v4beta1.CompleteQueryResponse.CompletionResult",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="suggestion",
            full_name="google.cloud.talent.v4beta1.CompleteQueryResponse.CompletionResult.suggestion",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="type",
            full_name="google.cloud.talent.v4beta1.CompleteQueryResponse.CompletionResult.type",
            index=1,
            number=2,
            type=14,
            cpp_type=8,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="image_uri",
            full_name="google.cloud.talent.v4beta1.CompleteQueryResponse.CompletionResult.image_uri",
            index=2,
            number=3,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=985,
    serialized_end=1122,
)

_COMPLETEQUERYRESPONSE = _descriptor.Descriptor(
    name="CompleteQueryResponse",
    full_name="google.cloud.talent.v4beta1.CompleteQueryResponse",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="completion_results",
            full_name="google.cloud.talent.v4beta1.CompleteQueryResponse.completion_results",
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="metadata",
            full_name="google.cloud.talent.v4beta1.CompleteQueryResponse.metadata",
            index=1,
            number=2,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
    ],
    extensions=[],
    nested_types=[_COMPLETEQUERYRESPONSE_COMPLETIONRESULT],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=797,
    serialized_end=1122,
)

_COMPLETEQUERYREQUEST.fields_by_name[
    "scope"
].enum_type = _COMPLETEQUERYREQUEST_COMPLETIONSCOPE
_COMPLETEQUERYREQUEST.fields_by_name[
    "type"
].enum_type = _COMPLETEQUERYREQUEST_COMPLETIONTYPE
_COMPLETEQUERYREQUEST_COMPLETIONSCOPE.containing_type = _COMPLETEQUERYREQUEST
_COMPLETEQUERYREQUEST_COMPLETIONTYPE.containing_type = _COMPLETEQUERYREQUEST
_COMPLETEQUERYRESPONSE_COMPLETIONRESULT.fields_by_name[
    "type"
].enum_type = _COMPLETEQUERYREQUEST_COMPLETIONTYPE
_COMPLETEQUERYRESPONSE_COMPLETIONRESULT.containing_type = _COMPLETEQUERYRESPONSE
_COMPLETEQUERYRESPONSE.fields_by_name[
    "completion_results"
].message_type = _COMPLETEQUERYRESPONSE_COMPLETIONRESULT
_COMPLETEQUERYRESPONSE.fields_by_name[
    "metadata"
].message_type = (
    google_dot_cloud_dot_talent__v4beta1_dot_proto_dot_common__pb2._RESPONSEMETADATA
)
DESCRIPTOR.message_types_by_name["CompleteQueryRequest"] = _COMPLETEQUERYREQUEST
DESCRIPTOR.message_types_by_name["CompleteQueryResponse"] = _COMPLETEQUERYRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

CompleteQueryRequest = _reflection.GeneratedProtocolMessageType(
    "CompleteQueryRequest",
    (_message.Message,),
    dict(
        DESCRIPTOR=_COMPLETEQUERYREQUEST,
        __module__="google.cloud.talent_v4beta1.proto.completion_service_pb2",
        __doc__="""Auto-complete parameters.
  
  
  Attributes:
      parent:
          Required. Resource name of tenant the completion is performed
          within.  The format is
          "projects/{project\_id}/tenants/{tenant\_id}", for example,
          "projects/foo/tenant/bar".  If tenant id is unspecified, the
          default tenant is used, for example, "projects/foo".
      query:
          Required. The query used to generate suggestions.  The maximum
          number of allowed characters is 255.
      language_codes:
          The list of languages of the query. This is the BCP-47
          language code, such as "en-US" or "sr-Latn". For more
          information, see `Tags for Identifying Languages
          <https://tools.ietf.org/html/bcp47>`__.  The maximum number of
          allowed characters is 255.
      page_size:
          Required. Completion result count.  The maximum allowed page
          size is 10.
      company:
          If provided, restricts completion to specified company.  The
          format is "projects/{project\_id}/tenants/{tenant\_id}/compani
          es/{company\_id}", for example,
          "projects/foo/tenants/bar/companies/baz".  If tenant id is
          unspecified, the default tenant is used, for example,
          "projects/foo".
      scope:
          The scope of the completion. The defaults is [CompletionScope.
          PUBLIC][google.cloud.talent.v4beta1.CompleteQueryRequest.Compl
          etionScope.PUBLIC].
      type:
          The completion topic. The default is [CompletionType.COMBINED]
          [google.cloud.talent.v4beta1.CompleteQueryRequest.CompletionTy
          pe.COMBINED].
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.talent.v4beta1.CompleteQueryRequest)
    ),
)
_sym_db.RegisterMessage(CompleteQueryRequest)

CompleteQueryResponse = _reflection.GeneratedProtocolMessageType(
    "CompleteQueryResponse",
    (_message.Message,),
    dict(
        CompletionResult=_reflection.GeneratedProtocolMessageType(
            "CompletionResult",
            (_message.Message,),
            dict(
                DESCRIPTOR=_COMPLETEQUERYRESPONSE_COMPLETIONRESULT,
                __module__="google.cloud.talent_v4beta1.proto.completion_service_pb2",
                __doc__="""Resource that represents completion results.
    
    
    Attributes:
        suggestion:
            The suggestion for the query.
        type:
            The completion topic.
        image_uri:
            The URI of the company image for [COMPANY\_NAME][google.cloud.
            talent.v4beta1.CompleteQueryRequest.CompletionType.COMPANY\_NA
            ME].
    """,
                # @@protoc_insertion_point(class_scope:google.cloud.talent.v4beta1.CompleteQueryResponse.CompletionResult)
            ),
        ),
        DESCRIPTOR=_COMPLETEQUERYRESPONSE,
        __module__="google.cloud.talent_v4beta1.proto.completion_service_pb2",
        __doc__="""Response of auto-complete query.
  
  
  Attributes:
      completion_results:
          Results of the matching job/company candidates.
      metadata:
          Additional information for the API invocation, such as the
          request tracking id.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.talent.v4beta1.CompleteQueryResponse)
    ),
)
_sym_db.RegisterMessage(CompleteQueryResponse)
_sym_db.RegisterMessage(CompleteQueryResponse.CompletionResult)


DESCRIPTOR._options = None
_COMPLETEQUERYREQUEST.fields_by_name["parent"]._options = None
_COMPLETEQUERYREQUEST.fields_by_name["query"]._options = None
_COMPLETEQUERYREQUEST.fields_by_name["page_size"]._options = None
_COMPLETEQUERYREQUEST.fields_by_name["company"]._options = None

_COMPLETION = _descriptor.ServiceDescriptor(
    name="Completion",
    full_name="google.cloud.talent.v4beta1.Completion",
    file=DESCRIPTOR,
    index=0,
    serialized_options=_b(
        "\312A\023jobs.googleapis.com\322AShttps://www.googleapis.com/auth/cloud-platform,https://www.googleapis.com/auth/jobs"
    ),
    serialized_start=1125,
    serialized_end=1466,
    methods=[
        _descriptor.MethodDescriptor(
            name="CompleteQuery",
            full_name="google.cloud.talent.v4beta1.Completion.CompleteQuery",
            index=0,
            containing_service=None,
            input_type=_COMPLETEQUERYREQUEST,
            output_type=_COMPLETEQUERYRESPONSE,
            serialized_options=_b(
                "\202\323\344\223\002Z\022//v4beta1/{parent=projects/*/tenants/*}:completeZ'\022%/v4beta1/{parent=projects/*}:complete"
            ),
        )
    ],
)
_sym_db.RegisterServiceDescriptor(_COMPLETION)

DESCRIPTOR.services_by_name["Completion"] = _COMPLETION

# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/cloud/talent_v4beta1/proto/tenant.proto

import sys

_b = sys.version_info[0] < 3 and (lambda x: x) or (lambda x: x.encode("latin1"))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2
from google.api import resource_pb2 as google_dot_api_dot_resource__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
    name="google/cloud/talent_v4beta1/proto/tenant.proto",
    package="google.cloud.talent.v4beta1",
    syntax="proto3",
    serialized_options=_b(
        "\n\037com.google.cloud.talent.v4beta1B\023TenantResourceProtoP\001ZAgoogle.golang.org/genproto/googleapis/cloud/talent/v4beta1;talent\242\002\003CTS\352A^\n#jobs.googleapis.com/TenantOrProject\022#projects/{project}/tenants/{tenant}\022\022projects/{project}"
    ),
    serialized_pb=_b(
        '\n.google/cloud/talent_v4beta1/proto/tenant.proto\x12\x1bgoogle.cloud.talent.v4beta1\x1a\x1fgoogle/api/field_behavior.proto\x1a\x19google/api/resource.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1cgoogle/api/annotations.proto"\xc3\x02\n\x06Tenant\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x18\n\x0b\x65xternal_id\x18\x02 \x01(\tB\x03\xe0\x41\x02\x12\x45\n\nusage_type\x18\x03 \x01(\x0e\x32\x31.google.cloud.talent.v4beta1.Tenant.DataUsageType\x12\x34\n,keyword_searchable_profile_custom_attributes\x18\x04 \x03(\t"N\n\rDataUsageType\x12\x1f\n\x1b\x44\x41TA_USAGE_TYPE_UNSPECIFIED\x10\x00\x12\x0e\n\nAGGREGATED\x10\x01\x12\x0c\n\x08ISOLATED\x10\x02:D\xea\x41\x41\n\x1ajobs.googleapis.com/Tenant\x12#projects/{project}/tenants/{tenant}B\xe2\x01\n\x1f\x63om.google.cloud.talent.v4beta1B\x13TenantResourceProtoP\x01ZAgoogle.golang.org/genproto/googleapis/cloud/talent/v4beta1;talent\xa2\x02\x03\x43TS\xea\x41^\n#jobs.googleapis.com/TenantOrProject\x12#projects/{project}/tenants/{tenant}\x12\x12projects/{project}b\x06proto3'
    ),
    dependencies=[
        google_dot_api_dot_field__behavior__pb2.DESCRIPTOR,
        google_dot_api_dot_resource__pb2.DESCRIPTOR,
        google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,
        google_dot_api_dot_annotations__pb2.DESCRIPTOR,
    ],
)


_TENANT_DATAUSAGETYPE = _descriptor.EnumDescriptor(
    name="DataUsageType",
    full_name="google.cloud.talent.v4beta1.Tenant.DataUsageType",
    filename=None,
    file=DESCRIPTOR,
    values=[
        _descriptor.EnumValueDescriptor(
            name="DATA_USAGE_TYPE_UNSPECIFIED",
            index=0,
            number=0,
            serialized_options=None,
            type=None,
        ),
        _descriptor.EnumValueDescriptor(
            name="AGGREGATED", index=1, number=1, serialized_options=None, type=None
        ),
        _descriptor.EnumValueDescriptor(
            name="ISOLATED", index=2, number=2, serialized_options=None, type=None
        ),
    ],
    containing_type=None,
    serialized_options=None,
    serialized_start=378,
    serialized_end=456,
)
_sym_db.RegisterEnumDescriptor(_TENANT_DATAUSAGETYPE)


_TENANT = _descriptor.Descriptor(
    name="Tenant",
    full_name="google.cloud.talent.v4beta1.Tenant",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="name",
            full_name="google.cloud.talent.v4beta1.Tenant.name",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="external_id",
            full_name="google.cloud.talent.v4beta1.Tenant.external_id",
            index=1,
            number=2,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=_b("\340A\002"),
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="usage_type",
            full_name="google.cloud.talent.v4beta1.Tenant.usage_type",
            index=2,
            number=3,
            type=14,
            cpp_type=8,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="keyword_searchable_profile_custom_attributes",
            full_name="google.cloud.talent.v4beta1.Tenant.keyword_searchable_profile_custom_attributes",
            index=3,
            number=4,
            type=9,
            cpp_type=9,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[_TENANT_DATAUSAGETYPE],
    serialized_options=_b(
        "\352AA\n\032jobs.googleapis.com/Tenant\022#projects/{project}/tenants/{tenant}"
    ),
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=203,
    serialized_end=526,
)

_TENANT.fields_by_name["usage_type"].enum_type = _TENANT_DATAUSAGETYPE
_TENANT_DATAUSAGETYPE.containing_type = _TENANT
DESCRIPTOR.message_types_by_name["Tenant"] = _TENANT
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Tenant = _reflection.GeneratedProtocolMessageType(
    "Tenant",
    (_message.Message,),
    dict(
        DESCRIPTOR=_TENANT,
        __module__="google.cloud.talent_v4beta1.proto.tenant_pb2",
        __doc__="""A Tenant resource represents a tenant in the service. A
  tenant is a group or entity that shares common access with specific
  privileges for resources like profiles. Customer may create multiple
  tenants to provide data isolation for different groups.
  
  
  Attributes:
      name:
          Required during tenant update.  The resource name for a
          tenant. This is generated by the service when a tenant is
          created.  The format is
          "projects/{project\_id}/tenants/{tenant\_id}", for example,
          "projects/foo/tenants/bar".
      external_id:
          Required. Client side tenant identifier, used to uniquely
          identify the tenant.  The maximum number of allowed characters
          is 255.
      usage_type:
          Indicates whether data owned by this tenant may be used to
          provide product improvements across other tenants.  Defaults
          behavior is [DataUsageType.ISOLATED][google.cloud.talent.v4bet
          a1.Tenant.DataUsageType.ISOLATED] if it's unset.
      keyword_searchable_profile_custom_attributes:
          A list of keys of filterable [Profile.custom\_attributes][goog
          le.cloud.talent.v4beta1.Profile.custom\_attributes], whose
          corresponding ``string_values`` are used in keyword searches.
          Profiles with ``string_values`` under these specified field
          keys are returned if any of the values match the search
          keyword. Custom field values with parenthesis, brackets and
          special symbols are not searchable as-is, and must be
          surrounded by quotes.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.talent.v4beta1.Tenant)
    ),
)
_sym_db.RegisterMessage(Tenant)


DESCRIPTOR._options = None
_TENANT.fields_by_name["external_id"]._options = None
_TENANT._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
#
# Copyright 2020 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     https://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.


from __future__ import absolute_import
import sys
import warnings

from google.cloud.talent_v4beta1 import types
from google.cloud.talent_v4beta1.gapic import application_service_client
from google.cloud.talent_v4beta1.gapic import company_service_client
from google.cloud.talent_v4beta1.gapic import completion_client
from google.cloud.talent_v4beta1.gapic import enums
from google.cloud.talent_v4beta1.gapic import event_service_client
from google.cloud.talent_v4beta1.gapic import job_service_client
from google.cloud.talent_v4beta1.gapic import profile_service_client
from google.cloud.talent_v4beta1.gapic import tenant_service_client


if sys.version_info[:2] == (2, 7):
    message = (
        "A future version of this library will drop support for Python 2.7."
        "More details about Python 2 support for Google Cloud Client Libraries"
        "can be found at https://cloud.google.com/python/docs/python2-sunset/"
    )
    warnings.warn(message, DeprecationWarning)


class ApplicationServiceClient(application_service_client.ApplicationServiceClient):
    __doc__ = application_service_client.ApplicationServiceClient.__doc__
    enums = enums


class CompanyServiceClient(company_service_client.CompanyServiceClient):
    __doc__ = company_service_client.CompanyServiceClient.__doc__
    enums = enums


class CompletionClient(completion_client.CompletionClient):
    __doc__ = completion_client.CompletionClient.__doc__
    enums = enums


class EventServiceClient(event_service_client.EventServiceClient):
    __doc__ = event_service_client.EventServiceClient.__doc__
    enums = enums


class JobServiceClient(job_service_client.JobServiceClient):
    __doc__ = job_service_client.JobServiceClient.__doc__
    enums = enums


class ProfileServiceClient(profile_service_client.ProfileServiceClient):
    __doc__ = profile_service_client.ProfileServiceClient.__doc__
    enums = enums


class TenantServiceClient(tenant_service_client.TenantServiceClient):
    __doc__ = tenant_service_client.TenantServiceClient.__doc__
    enums = enums


__all__ = (
    "enums",
    "types",
    "ApplicationServiceClient",
    "CompanyServiceClient",
    "CompletionClient",
    "EventServiceClient",
    "JobServiceClient",
    "ProfileServiceClient",
    "TenantServiceClient",
)



# Copyright 2019 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

import io
import os

import setuptools


# Package metadata.

name = "google-cloud-talent"
description = "Google Cloud Talent Solution API client library"
version = "0.5.0"
# Should be one of:
# 'Development Status :: 3 - Alpha'
# 'Development Status :: 4 - Beta'
# 'Development Status :: 5 - Production/Stable'
release_status = "Development Status :: 3 - Alpha"
dependencies = ["google-api-core[grpc] >= 1.14.0, < 2.0.0dev"]
extras = {}


# Setup boilerplate below this line.

package_root = os.path.abspath(os.path.dirname(__file__))

readme_filename = os.path.join(package_root, "README.rst")
with io.open(readme_filename, encoding="utf-8") as readme_file:
    readme = readme_file.read()

# Only include packages under the 'google' namespace. Do not include tests,
# benchmarks, etc.
packages = [
    package for package in setuptools.find_packages() if package.startswith("google")
]

# Determine which namespaces are needed.
namespaces = ["google"]
if "google.cloud" in packages:
    namespaces.append("google.cloud")


setuptools.setup(
    name=name,
    version=version,
    description=description,
    long_description=readme,
    author="Google LLC",
    author_email="googleapis-packages@google.com",
    license="Apache 2.0",
    url="https://github.com/googleapis/python-talent",
    classifiers=[
        release_status,
        "Intended Audience :: Developers",
        "License :: OSI Approved :: Apache Software License",
        "Programming Language :: Python",
        "Programming Language :: Python :: 2",
        "Programming Language :: Python :: 2.7",
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3.5",
        "Programming Language :: Python :: 3.6",
        "Programming Language :: Python :: 3.7",
        "Operating System :: OS Independent",
        "Topic :: Internet",
    ],
    platforms="Posix; MacOS X; Windows",
    packages=packages,
    namespace_packages=namespaces,
    install_requires=dependencies,
    extras_require=extras,
    python_requires=">=2.7,!=3.0.*,!=3.1.*,!=3.2.*,!=3.3.*",
    include_package_data=True,
    zip_safe=False,
)



# -*- coding: utf-8 -*-
#
# Copyright 2020 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     https://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

"""Unit tests."""

import mock
import pytest

from google.rpc import status_pb2

from google.cloud import talent_v4beta1
from google.cloud.talent_v4beta1.proto import common_pb2
from google.cloud.talent_v4beta1.proto import job_pb2
from google.cloud.talent_v4beta1.proto import job_service_pb2
from google.longrunning import operations_pb2
from google.protobuf import empty_pb2


class MultiCallableStub(object):
    """Stub for the grpc.UnaryUnaryMultiCallable interface."""

    def __init__(self, method, channel_stub):
        self.method = method
        self.channel_stub = channel_stub

    def __call__(self, request, timeout=None, metadata=None, credentials=None):
        self.channel_stub.requests.append((self.method, request))

        response = None
        if self.channel_stub.responses:
            response = self.channel_stub.responses.pop()

        if isinstance(response, Exception):
            raise response

        if response:
            return response


class ChannelStub(object):
    """Stub for the grpc.Channel interface."""

    def __init__(self, responses=[]):
        self.responses = responses
        self.requests = []

    def unary_unary(self, method, request_serializer=None, response_deserializer=None):
        return MultiCallableStub(method, self)


class CustomException(Exception):
    pass


class TestJobServiceClient(object):
    def test_create_job(self):
        # Setup Expected Response
        name = "name3373707"
        company = "company950484093"
        requisition_id = "requisitionId980224926"
        title = "title110371416"
        description = "description-1724546052"
        department = "department848184146"
        incentives = "incentives-1262874520"
        language_code = "languageCode-412800396"
        promotion_value = 353413845
        qualifications = "qualifications1903501412"
        responsibilities = "responsibilities-926952660"
        company_display_name = "companyDisplayName1982424170"
        expected_response = {
            "name": name,
            "company": company,
            "requisition_id": requisition_id,
            "title": title,
            "description": description,
            "department": department,
            "incentives": incentives,
            "language_code": language_code,
            "promotion_value": promotion_value,
            "qualifications": qualifications,
            "responsibilities": responsibilities,
            "company_display_name": company_display_name,
        }
        expected_response = job_pb2.Job(**expected_response)

        # Mock the API response
        channel = ChannelStub(responses=[expected_response])
        patch = mock.patch("google.api_core.grpc_helpers.create_channel")
        with patch as create_channel:
            create_channel.return_value = channel
            client = talent_v4beta1.JobServiceClient()

        # Setup Request
        parent = client.tenant_path("[PROJECT]", "[TENANT]")
        job = {}

        response = client.create_job(parent, job)
        assert expected_response == response

        assert len(channel.requests) == 1
        expected_request = job_service_pb2.CreateJobRequest(parent=parent, job=job)
        actual_request = channel.requests[0][1]
        assert expected_request == actual_request

    def test_create_job_exception(self):
        # Mock the API response
        channel = ChannelStub(responses=[CustomException()])
        patch = mock.patch("google.api_core.grpc_helpers.create_channel")
        with patch as create_channel:
            create_channel.return_value = channel
            client = talent_v4beta1.JobServiceClient()

        # Setup request
        parent = client.tenant_path("[PROJECT]", "[TENANT]")
        job = {}

        with pytest.raises(CustomException):
            client.create_job(parent, job)

    def test_get_job(self):
        # Setup Expected Response
        name_2 = "name2-1052831874"
        company = "company950484093"
        requisition_id = "requisitionId980224926"
        title = "title110371416"
        description = "description-1724546052"
        department = "department848184146"
        incentives = "incentives-1262874520"
        language_code = "languageCode-412800396"
        promotion_value = 353413845
        qualifications = "qualifications1903501412"
        responsibilities = "responsibilities-926952660"
        company_display_name = "companyDisplayName1982424170"
        expected_response = {
            "name": name_2,
            "company": company,
            "requisition_id": requisition_id,
            "title": title,
            "description": description,
            "department": department,
            "incentives": incentives,
            "language_code": language_code,
            "promotion_value": promotion_value,
            "qualifications": qualifications,
            "responsibilities": responsibilities,
            "company_display_name": company_display_name,
        }
        expected_response = job_pb2.Job(**expected_response)

        # Mock the API response
        channel = ChannelStub(responses=[expected_response])
        patch = mock.patch("google.api_core.grpc_helpers.create_channel")
        with patch as create_channel:
            create_channel.return_value = channel
            client = talent_v4beta1.JobServiceClient()

        # Setup Request
        name = client.job_path("[PROJECT]", "[TENANT]", "[JOBS]")

        response = client.get_job(name)
        assert expected_response == response

        assert len(channel.requests) == 1
        expected_request = job_service_pb2.GetJobRequest(name=name)
        actual_request = channel.requests[0][1]
        assert expected_request == actual_request

    def test_get_job_exception(self):
        # Mock the API response
        channel = ChannelStub(responses=[CustomException()])
        patch = mock.patch("google.api_core.grpc_helpers.create_channel")
        with patch as create_channel:
            create_channel.return_value = channel
            client = talent_v4beta1.JobServiceClient()

        # Setup request
        name = client.job_path("[PROJECT]", "[TENANT]", "[JOBS]")

        with pytest.raises(CustomException):
            client.get_job(name)

    def test_update_job(self):
        # Setup Expected Response
        name = "name3373707"
        company = "company950484093"
        requisition_id = "requisitionId980224926"
        title = "title110371416"
        description = "description-1724546052"
        department = "department848184146"
        incentives = "incentives-1262874520"
        language_code = "languageCode-412800396"
        promotion_value = 353413845
        qualifications = "qualifications1903501412"
        responsibilities = "responsibilities-926952660"
        company_display_name = "companyDisplayName1982424170"
        expected_response = {
            "name": name,
            "company": company,
            "requisition_id": requisition_id,
            "title": title,
            "description": description,
            "department": department,
            "incentives": incentives,
            "language_code": language_code,
            "promotion_value": promotion_value,
            "qualifications": qualifications,
            "responsibilities": responsibilities,
            "company_display_name": company_display_name,
        }
        expected_response = job_pb2.Job(**expected_response)

        # Mock the API response
        channel = ChannelStub(responses=[expected_response])
        patch = mock.patch("google.api_core.grpc_helpers.create_channel")
        with patch as create_channel:
            create_channel.return_value = channel
            client = talent_v4beta1.JobServiceClient()

        # Setup Request
        job = {}

        response = client.update_job(job)
        assert expected_response == response

        assert len(channel.requests) == 1
        expected_request = job_service_pb2.UpdateJobRequest(job=job)
        actual_request = channel.requests[0][1]
        assert expected_request == actual_request

    def test_update_job_exception(self):
        # Mock the API response
        channel = ChannelStub(responses=[CustomException()])
        patch = mock.patch("google.api_core.grpc_helpers.create_channel")
        with patch as create_channel:
            create_channel.return_value = channel
            client = talent_v4beta1.JobServiceClient()

        # Setup request
        job = {}

        with pytest.raises(CustomException):
            client.update_job(job)

    def test_delete_job(self):
        channel = ChannelStub()
        patch = mock.patch("google.api_core.grpc_helpers.create_channel")
        with patch as create_channel:
            create_channel.return_value = channel
            client = talent_v4beta1.JobServiceClient()

        # Setup Request
        name = client.job_path("[PROJECT]", "[TENANT]", "[JOBS]")

        client.delete_job(name)

        assert len(channel.requests) == 1
        expected_request = job_service_pb2.DeleteJobRequest(name=name)
        actual_request = channel.requests[0][1]
        assert expected_request == actual_request

    def test_delete_job_exception(self):
        # Mock the API response
        channel = ChannelStub(responses=[CustomException()])
        patch = mock.patch("google.api_core.grpc_helpers.create_channel")
        with patch as create_channel:
            create_channel.return_value = channel
            client = talent_v4beta1.JobServiceClient()

        # Setup request
        name = client.job_path("[PROJECT]", "[TENANT]", "[JOBS]")

        with pytest.raises(CustomException):
            client.delete_job(name)

    def test_list_jobs(self):
        # Setup Expected Response
        next_page_token = ""
        jobs_element = {}
        jobs = [jobs_element]
        expected_response = {"next_page_token": next_page_token, "jobs": jobs}
        expected_response = job_service_pb2.ListJobsResponse(**expected_response)

        # Mock the API response
        channel = ChannelStub(responses=[expected_response])
        patch = mock.patch("google.api_core.grpc_helpers.create_channel")
        with patch as create_channel:
            create_channel.return_value = channel
            client = talent_v4beta1.JobServiceClient()

        # Setup Request
        parent = client.tenant_path("[PROJECT]", "[TENANT]")
        filter_ = "filter-1274492040"

        paged_list_response = client.list_jobs(parent, filter_)
        resources = list(paged_list_response)
        assert len(resources) == 1

        assert expected_response.jobs[0] == resources[0]

        assert len(channel.requests) == 1
        expected_request = job_service_pb2.ListJobsRequest(
            parent=parent, filter=filter_
        )
        actual_request = channel.requests[0][1]
        assert expected_request == actual_request

    def test_list_jobs_exception(self):
        channel = ChannelStub(responses=[CustomException()])
        patch = mock.patch("google.api_core.grpc_helpers.create_channel")
        with patch as create_channel:
            create_channel.return_value = channel
            client = talent_v4beta1.JobServiceClient()

        # Setup request
        parent = client.tenant_path("[PROJECT]", "[TENANT]")
        filter_ = "filter-1274492040"

        paged_list_response = client.list_jobs(parent, filter_)
        with pytest.raises(CustomException):
            list(paged_list_response)

    def test_batch_delete_jobs(self):
        channel = ChannelStub()
        patch = mock.patch("google.api_core.grpc_helpers.create_channel")
        with patch as create_channel:
            create_channel.return_value = channel
            client = talent_v4beta1.JobServiceClient()

        # Setup Request
        parent = client.tenant_path("[PROJECT]", "[TENANT]")
        filter_ = "filter-1274492040"

        client.batch_delete_jobs(parent, filter_)

        assert len(channel.requests) == 1
        expected_request = job_service_pb2.BatchDeleteJobsRequest(
            parent=parent, filter=filter_
        )
        actual_request = channel.requests[0][1]
        assert expected_request == actual_request

    def test_batch_delete_jobs_exception(self):
        # Mock the API response
        channel = ChannelStub(responses=[CustomException()])
        patch = mock.patch("google.api_core.grpc_helpers.create_channel")
        with patch as create_channel:
            create_channel.return_value = channel
            client = talent_v4beta1.JobServiceClient()

        # Setup request
        parent = client.tenant_path("[PROJECT]", "[TENANT]")
        filter_ = "filter-1274492040"

        with pytest.raises(CustomException):
            client.batch_delete_jobs(parent, filter_)

    def test_search_jobs(self):
        # Setup Expected Response
        next_page_token = ""
        estimated_total_size = 1882144769
        total_size = 705419236
        broadened_query_jobs_count = 1432104658
        matching_jobs_element = {}
        matching_jobs = [matching_jobs_element]
        expected_response = {
            "next_page_token": next_page_token,
            "estimated_total_size": estimated_total_size,
            "total_size": total_size,
            "broadened_query_jobs_count": broadened_query_jobs_count,
            "matching_jobs": matching_jobs,
        }
        expected_response = job_service_pb2.SearchJobsResponse(**expected_response)

        # Mock the API response
        channel = ChannelStub(responses=[expected_response])
        patch = mock.patch("google.api_core.grpc_helpers.create_channel")
        with patch as create_channel:
            create_channel.return_value = channel
            client = talent_v4beta1.JobServiceClient()

        # Setup Request
        parent = client.tenant_path("[PROJECT]", "[TENANT]")
        request_metadata = {}

        paged_list_response = client.search_jobs(parent, request_metadata)
        resources = list(paged_list_response)
        assert len(resources) == 1

        assert expected_response.matching_jobs[0] == resources[0]

        assert len(channel.requests) == 1
        expected_request = job_service_pb2.SearchJobsRequest(
            parent=parent, request_metadata=request_metadata
        )
        actual_request = channel.requests[0][1]
        assert expected_request == actual_request

    def test_search_jobs_exception(self):
        channel = ChannelStub(responses=[CustomException()])
        patch = mock.patch("google.api_core.grpc_helpers.create_channel")
        with patch as create_channel:
            create_channel.return_value = channel
            client = talent_v4beta1.JobServiceClient()

        # Setup request
        parent = client.tenant_path("[PROJECT]", "[TENANT]")
        request_metadata = {}

        paged_list_response = client.search_jobs(parent, request_metadata)
        with pytest.raises(CustomException):
            list(paged_list_response)

    def test_search_jobs_for_alert(self):
        # Setup Expected Response
        next_page_token = ""
        estimated_total_size = 1882144769
        total_size = 705419236
        broadened_query_jobs_count = 1432104658
        matching_jobs_element = {}
        matching_jobs = [matching_jobs_element]
        expected_response = {
            "next_page_token": next_page_token,
            "estimated_total_size": estimated_total_size,
            "total_size": total_size,
            "broadened_query_jobs_count": broadened_query_jobs_count,
            "matching_jobs": matching_jobs,
        }
        expected_response = job_service_pb2.SearchJobsResponse(**expected_response)

        # Mock the API response
        channel = ChannelStub(responses=[expected_response])
        patch = mock.patch("google.api_core.grpc_helpers.create_channel")
        with patch as create_channel:
            create_channel.return_value = channel
            client = talent_v4beta1.JobServiceClient()

        # Setup Request
        parent = client.tenant_path("[PROJECT]", "[TENANT]")
        request_metadata = {}

        paged_list_response = client.search_jobs_for_alert(parent, request_metadata)
        resources = list(paged_list_response)
        assert len(resources) == 1

        assert expected_response.matching_jobs[0] == resources[0]

        assert len(channel.requests) == 1
        expected_request = job_service_pb2.SearchJobsRequest(
            parent=parent, request_metadata=request_metadata
        )
        actual_request = channel.requests[0][1]
        assert expected_request == actual_request

    def test_search_jobs_for_alert_exception(self):
        channel = ChannelStub(responses=[CustomException()])
        patch = mock.patch("google.api_core.grpc_helpers.create_channel")
        with patch as create_channel:
            create_channel.return_value = channel
            client = talent_v4beta1.JobServiceClient()

        # Setup request
        parent = client.tenant_path("[PROJECT]", "[TENANT]")
        request_metadata = {}

        paged_list_response = client.search_jobs_for_alert(parent, request_metadata)
        with pytest.raises(CustomException):
            list(paged_list_response)

    def test_batch_create_jobs(self):
        # Setup Expected Response
        expected_response = {}
        expected_response = job_service_pb2.JobOperationResult(**expected_response)
        operation = operations_pb2.Operation(
            name="operations/test_batch_create_jobs", done=True
        )
        operation.response.Pack(expected_response)

        # Mock the API response
        channel = ChannelStub(responses=[operation])
        patch = mock.patch("google.api_core.grpc_helpers.create_channel")
        with patch as create_channel:
            create_channel.return_value = channel
            client = talent_v4beta1.JobServiceClient()

        # Setup Request
        parent = client.tenant_path("[PROJECT]", "[TENANT]")
        jobs = []

        response = client.batch_create_jobs(parent, jobs)
        result = response.result()
        assert expected_response == result

        assert len(channel.requests) == 1
        expected_request = job_service_pb2.BatchCreateJobsRequest(
            parent=parent, jobs=jobs
        )
        actual_request = channel.requests[0][1]
        assert expected_request == actual_request

    def test_batch_create_jobs_exception(self):
        # Setup Response
        error = status_pb2.Status()
        operation = operations_pb2.Operation(
            name="operations/test_batch_create_jobs_exception", done=True
        )
        operation.error.CopyFrom(error)

        # Mock the API response
        channel = ChannelStub(responses=[operation])
        patch = mock.patch("google.api_core.grpc_helpers.create_channel")
        with patch as create_channel:
            create_channel.return_value = channel
            client = talent_v4beta1.JobServiceClient()

        # Setup Request
        parent = client.tenant_path("[PROJECT]", "[TENANT]")
        jobs = []

        response = client.batch_create_jobs(parent, jobs)
        exception = response.exception()
        assert exception.errors[0] == error

    def test_batch_update_jobs(self):
        # Setup Expected Response
        expected_response = {}
        expected_response = job_service_pb2.JobOperationResult(**expected_response)
        operation = operations_pb2.Operation(
            name="operations/test_batch_update_jobs", done=True
        )
        operation.response.Pack(expected_response)

        # Mock the API response
        channel = ChannelStub(responses=[operation])
        patch = mock.patch("google.api_core.grpc_helpers.create_channel")
        with patch as create_channel:
            create_channel.return_value = channel
            client = talent_v4beta1.JobServiceClient()

        # Setup Request
        parent = client.tenant_path("[PROJECT]", "[TENANT]")
        jobs = []

        response = client.batch_update_jobs(parent, jobs)
        result = response.result()
        assert expected_response == result

        assert len(channel.requests) == 1
        expected_request = job_service_pb2.BatchUpdateJobsRequest(
            parent=parent, jobs=jobs
        )
        actual_request = channel.requests[0][1]
        assert expected_request == actual_request

    def test_batch_update_jobs_exception(self):
        # Setup Response
        error = status_pb2.Status()
        operation = operations_pb2.Operation(
            name="operations/test_batch_update_jobs_exception", done=True
        )
        operation.error.CopyFrom(error)

        # Mock the API response
        channel = ChannelStub(responses=[operation])
        patch = mock.patch("google.api_core.grpc_helpers.create_channel")
        with patch as create_channel:
            create_channel.return_value = channel
            client = talent_v4beta1.JobServiceClient()

        # Setup Request
        parent = client.tenant_path("[PROJECT]", "[TENANT]")
        jobs = []

        response = client.batch_update_jobs(parent, jobs)
        exception = response.exception()
        assert exception.errors[0] == error



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/cloud/talent_v4beta1/proto/company_service.proto

import sys

_b = sys.version_info[0] < 3 and (lambda x: x) or (lambda x: x.encode("latin1"))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.api import client_pb2 as google_dot_api_dot_client__pb2
from google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2
from google.api import resource_pb2 as google_dot_api_dot_resource__pb2
from google.cloud.talent_v4beta1.proto import (
    common_pb2 as google_dot_cloud_dot_talent__v4beta1_dot_proto_dot_common__pb2,
)
from google.cloud.talent_v4beta1.proto import (
    company_pb2 as google_dot_cloud_dot_talent__v4beta1_dot_proto_dot_company__pb2,
)
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
    name="google/cloud/talent_v4beta1/proto/company_service.proto",
    package="google.cloud.talent.v4beta1",
    syntax="proto3",
    serialized_options=_b(
        "\n\037com.google.cloud.talent.v4beta1B\023CompanyServiceProtoP\001ZAgoogle.golang.org/genproto/googleapis/cloud/talent/v4beta1;talent\242\002\003CTS"
    ),
    serialized_pb=_b(
        '\n7google/cloud/talent_v4beta1/proto/company_service.proto\x12\x1bgoogle.cloud.talent.v4beta1\x1a\x1cgoogle/api/annotations.proto\x1a\x17google/api/client.proto\x1a\x1fgoogle/api/field_behavior.proto\x1a\x19google/api/resource.proto\x1a.google/cloud/talent_v4beta1/proto/common.proto\x1a/google/cloud/talent_v4beta1/proto/company.proto\x1a\x1bgoogle/protobuf/empty.proto\x1a google/protobuf/field_mask.proto"\x87\x01\n\x14\x43reateCompanyRequest\x12\x33\n\x06parent\x18\x01 \x01(\tB#\xe0\x41\x02\xfa\x41\x1d\x12\x1bjobs.googleapis.com/Company\x12:\n\x07\x63ompany\x18\x02 \x01(\x0b\x32$.google.cloud.talent.v4beta1.CompanyB\x03\xe0\x41\x02"F\n\x11GetCompanyRequest\x12\x31\n\x04name\x18\x01 \x01(\tB#\xe0\x41\x02\xfa\x41\x1d\n\x1bjobs.googleapis.com/Company"\x83\x01\n\x14UpdateCompanyRequest\x12:\n\x07\x63ompany\x18\x01 \x01(\x0b\x32$.google.cloud.talent.v4beta1.CompanyB\x03\xe0\x41\x02\x12/\n\x0bupdate_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMask"I\n\x14\x44\x65leteCompanyRequest\x12\x31\n\x04name\x18\x01 \x01(\tB#\xe0\x41\x02\xfa\x41\x1d\n\x1bjobs.googleapis.com/Company"\x95\x01\n\x14ListCompaniesRequest\x12;\n\x06parent\x18\x01 \x01(\tB+\xe0\x41\x02\xfa\x41%\n#jobs.googleapis.com/TenantOrProject\x12\x12\n\npage_token\x18\x02 \x01(\t\x12\x11\n\tpage_size\x18\x03 \x01(\x05\x12\x19\n\x11require_open_jobs\x18\x04 \x01(\x08"\xaa\x01\n\x15ListCompaniesResponse\x12\x37\n\tcompanies\x18\x01 \x03(\x0b\x32$.google.cloud.talent.v4beta1.Company\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\x12?\n\x08metadata\x18\x03 \x01(\x0b\x32-.google.cloud.talent.v4beta1.ResponseMetadata2\xd2\t\n\x0e\x43ompanyService\x12\xe3\x01\n\rCreateCompany\x12\x31.google.cloud.talent.v4beta1.CreateCompanyRequest\x1a$.google.cloud.talent.v4beta1.Company"y\x82\xd3\xe4\x93\x02\x62"0/v4beta1/{parent=projects/*/tenants/*}/companies:\x01*Z+"&/v4beta1/{parent=projects/*}/companies:\x01*\xda\x41\x0eparent,company\x12\xcd\x01\n\nGetCompany\x12..google.cloud.talent.v4beta1.GetCompanyRequest\x1a$.google.cloud.talent.v4beta1.Company"i\x82\xd3\xe4\x93\x02\\\x12\x30/v4beta1/{name=projects/*/tenants/*/companies/*}Z(\x12&/v4beta1/{name=projects/*/companies/*}\xda\x41\x04name\x12\xed\x01\n\rUpdateCompany\x12\x31.google.cloud.talent.v4beta1.UpdateCompanyRequest\x1a$.google.cloud.talent.v4beta1.Company"\x82\x01\x82\xd3\xe4\x93\x02r28/v4beta1/{company.name=projects/*/tenants/*/companies/*}:\x01*Z32./v4beta1/{company.name=projects/*/companies/*}:\x01*\xda\x41\x07\x63ompany\x12\xc5\x01\n\rDeleteCompany\x12\x31.google.cloud.talent.v4beta1.DeleteCompanyRequest\x1a\x16.google.protobuf.Empty"i\x82\xd3\xe4\x93\x02\\*0/v4beta1/{name=projects/*/tenants/*/companies/*}Z(*&/v4beta1/{name=projects/*/companies/*}\xda\x41\x04name\x12\xe3\x01\n\rListCompanies\x12\x31.google.cloud.talent.v4beta1.ListCompaniesRequest\x1a\x32.google.cloud.talent.v4beta1.ListCompaniesResponse"k\x82\xd3\xe4\x93\x02\\\x12\x30/v4beta1/{parent=projects/*/tenants/*}/companiesZ(\x12&/v4beta1/{parent=projects/*}/companies\xda\x41\x06parent\x1al\xca\x41\x13jobs.googleapis.com\xd2\x41Shttps://www.googleapis.com/auth/cloud-platform,https://www.googleapis.com/auth/jobsB\x81\x01\n\x1f\x63om.google.cloud.talent.v4beta1B\x13\x43ompanyServiceProtoP\x01ZAgoogle.golang.org/genproto/googleapis/cloud/talent/v4beta1;talent\xa2\x02\x03\x43TSb\x06proto3'
    ),
    dependencies=[
        google_dot_api_dot_annotations__pb2.DESCRIPTOR,
        google_dot_api_dot_client__pb2.DESCRIPTOR,
        google_dot_api_dot_field__behavior__pb2.DESCRIPTOR,
        google_dot_api_dot_resource__pb2.DESCRIPTOR,
        google_dot_cloud_dot_talent__v4beta1_dot_proto_dot_common__pb2.DESCRIPTOR,
        google_dot_cloud_dot_talent__v4beta1_dot_proto_dot_company__pb2.DESCRIPTOR,
        google_dot_protobuf_dot_empty__pb2.DESCRIPTOR,
        google_dot_protobuf_dot_field__mask__pb2.DESCRIPTOR,
    ],
)


_CREATECOMPANYREQUEST = _descriptor.Descriptor(
    name="CreateCompanyRequest",
    full_name="google.cloud.talent.v4beta1.CreateCompanyRequest",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="parent",
            full_name="google.cloud.talent.v4beta1.CreateCompanyRequest.parent",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=_b(
                "\340A\002\372A\035\022\033jobs.googleapis.com/Company"
            ),
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="company",
            full_name="google.cloud.talent.v4beta1.CreateCompanyRequest.company",
            index=1,
            number=2,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=_b("\340A\002"),
            file=DESCRIPTOR,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=364,
    serialized_end=499,
)


_GETCOMPANYREQUEST = _descriptor.Descriptor(
    name="GetCompanyRequest",
    full_name="google.cloud.talent.v4beta1.GetCompanyRequest",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="name",
            full_name="google.cloud.talent.v4beta1.GetCompanyRequest.name",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=_b(
                "\340A\002\372A\035\n\033jobs.googleapis.com/Company"
            ),
            file=DESCRIPTOR,
        )
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=501,
    serialized_end=571,
)


_UPDATECOMPANYREQUEST = _descriptor.Descriptor(
    name="UpdateCompanyRequest",
    full_name="google.cloud.talent.v4beta1.UpdateCompanyRequest",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="company",
            full_name="google.cloud.talent.v4beta1.UpdateCompanyRequest.company",
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=_b("\340A\002"),
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="update_mask",
            full_name="google.cloud.talent.v4beta1.UpdateCompanyRequest.update_mask",
            index=1,
            number=2,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=574,
    serialized_end=705,
)


_DELETECOMPANYREQUEST = _descriptor.Descriptor(
    name="DeleteCompanyRequest",
    full_name="google.cloud.talent.v4beta1.DeleteCompanyRequest",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="name",
            full_name="google.cloud.talent.v4beta1.DeleteCompanyRequest.name",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=_b(
                "\340A\002\372A\035\n\033jobs.googleapis.com/Company"
            ),
            file=DESCRIPTOR,
        )
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=707,
    serialized_end=780,
)


_LISTCOMPANIESREQUEST = _descriptor.Descriptor(
    name="ListCompaniesRequest",
    full_name="google.cloud.talent.v4beta1.ListCompaniesRequest",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="parent",
            full_name="google.cloud.talent.v4beta1.ListCompaniesRequest.parent",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=_b(
                "\340A\002\372A%\n#jobs.googleapis.com/TenantOrProject"
            ),
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="page_token",
            full_name="google.cloud.talent.v4beta1.ListCompaniesRequest.page_token",
            index=1,
            number=2,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="page_size",
            full_name="google.cloud.talent.v4beta1.ListCompaniesRequest.page_size",
            index=2,
            number=3,
            type=5,
            cpp_type=1,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="require_open_jobs",
            full_name="google.cloud.talent.v4beta1.ListCompaniesRequest.require_open_jobs",
            index=3,
            number=4,
            type=8,
            cpp_type=7,
            label=1,
            has_default_value=False,
            default_value=False,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=783,
    serialized_end=932,
)


_LISTCOMPANIESRESPONSE = _descriptor.Descriptor(
    name="ListCompaniesResponse",
    full_name="google.cloud.talent.v4beta1.ListCompaniesResponse",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="companies",
            full_name="google.cloud.talent.v4beta1.ListCompaniesResponse.companies",
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="next_page_token",
            full_name="google.cloud.talent.v4beta1.ListCompaniesResponse.next_page_token",
            index=1,
            number=2,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="metadata",
            full_name="google.cloud.talent.v4beta1.ListCompaniesResponse.metadata",
            index=2,
            number=3,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=935,
    serialized_end=1105,
)

_CREATECOMPANYREQUEST.fields_by_name[
    "company"
].message_type = (
    google_dot_cloud_dot_talent__v4beta1_dot_proto_dot_company__pb2._COMPANY
)
_UPDATECOMPANYREQUEST.fields_by_name[
    "company"
].message_type = (
    google_dot_cloud_dot_talent__v4beta1_dot_proto_dot_company__pb2._COMPANY
)
_UPDATECOMPANYREQUEST.fields_by_name[
    "update_mask"
].message_type = google_dot_protobuf_dot_field__mask__pb2._FIELDMASK
_LISTCOMPANIESRESPONSE.fields_by_name[
    "companies"
].message_type = (
    google_dot_cloud_dot_talent__v4beta1_dot_proto_dot_company__pb2._COMPANY
)
_LISTCOMPANIESRESPONSE.fields_by_name[
    "metadata"
].message_type = (
    google_dot_cloud_dot_talent__v4beta1_dot_proto_dot_common__pb2._RESPONSEMETADATA
)
DESCRIPTOR.message_types_by_name["CreateCompanyRequest"] = _CREATECOMPANYREQUEST
DESCRIPTOR.message_types_by_name["GetCompanyRequest"] = _GETCOMPANYREQUEST
DESCRIPTOR.message_types_by_name["UpdateCompanyRequest"] = _UPDATECOMPANYREQUEST
DESCRIPTOR.message_types_by_name["DeleteCompanyRequest"] = _DELETECOMPANYREQUEST
DESCRIPTOR.message_types_by_name["ListCompaniesRequest"] = _LISTCOMPANIESREQUEST
DESCRIPTOR.message_types_by_name["ListCompaniesResponse"] = _LISTCOMPANIESRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

CreateCompanyRequest = _reflection.GeneratedProtocolMessageType(
    "CreateCompanyRequest",
    (_message.Message,),
    dict(
        DESCRIPTOR=_CREATECOMPANYREQUEST,
        __module__="google.cloud.talent_v4beta1.proto.company_service_pb2",
        __doc__="""The Request of the CreateCompany method.
  
  
  Attributes:
      parent:
          Required. Resource name of the tenant under which the company
          is created.  The format is
          "projects/{project\_id}/tenants/{tenant\_id}", for example,
          "projects/foo/tenant/bar". If tenant id is unspecified, a
          default tenant is created, for example, "projects/foo".
      company:
          Required. The company to be created.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.talent.v4beta1.CreateCompanyRequest)
    ),
)
_sym_db.RegisterMessage(CreateCompanyRequest)

GetCompanyRequest = _reflection.GeneratedProtocolMessageType(
    "GetCompanyRequest",
    (_message.Message,),
    dict(
        DESCRIPTOR=_GETCOMPANYREQUEST,
        __module__="google.cloud.talent_v4beta1.proto.company_service_pb2",
        __doc__="""Request for getting a company by name.
  
  
  Attributes:
      name:
          Required. The resource name of the company to be retrieved.
          The format is "projects/{project\_id}/tenants/{tenant\_id}/com
          panies/{company\_id}", for example, "projects/api-test-
          project/tenants/foo/companies/bar".  If tenant id is
          unspecified, the default tenant is used, for example,
          "projects/api-test-project/companies/bar".
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.talent.v4beta1.GetCompanyRequest)
    ),
)
_sym_db.RegisterMessage(GetCompanyRequest)

UpdateCompanyRequest = _reflection.GeneratedProtocolMessageType(
    "UpdateCompanyRequest",
    (_message.Message,),
    dict(
        DESCRIPTOR=_UPDATECOMPANYREQUEST,
        __module__="google.cloud.talent_v4beta1.proto.company_service_pb2",
        __doc__="""Request for updating a specified company.
  
  
  Attributes:
      company:
          Required. The company resource to replace the current resource
          in the system.
      update_mask:
          Strongly recommended for the best service experience.  If [upd
          ate\_mask][google.cloud.talent.v4beta1.UpdateCompanyRequest.up
          date\_mask] is provided, only the specified fields in [company
          ][google.cloud.talent.v4beta1.UpdateCompanyRequest.company]
          are updated. Otherwise all the fields are updated.  A field
          mask to specify the company fields to be updated. Only top
          level fields of [Company][google.cloud.talent.v4beta1.Company]
          are supported.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.talent.v4beta1.UpdateCompanyRequest)
    ),
)
_sym_db.RegisterMessage(UpdateCompanyRequest)

DeleteCompanyRequest = _reflection.GeneratedProtocolMessageType(
    "DeleteCompanyRequest",
    (_message.Message,),
    dict(
        DESCRIPTOR=_DELETECOMPANYREQUEST,
        __module__="google.cloud.talent_v4beta1.proto.company_service_pb2",
        __doc__="""Request to delete a company.
  
  
  Attributes:
      name:
          Required. The resource name of the company to be deleted.  The
          format is "projects/{project\_id}/tenants/{tenant\_id}/compani
          es/{company\_id}", for example,
          "projects/foo/tenants/bar/companies/baz".  If tenant id is
          unspecified, the default tenant is used, for example,
          "projects/foo/companies/bar".
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.talent.v4beta1.DeleteCompanyRequest)
    ),
)
_sym_db.RegisterMessage(DeleteCompanyRequest)

ListCompaniesRequest = _reflection.GeneratedProtocolMessageType(
    "ListCompaniesRequest",
    (_message.Message,),
    dict(
        DESCRIPTOR=_LISTCOMPANIESREQUEST,
        __module__="google.cloud.talent_v4beta1.proto.company_service_pb2",
        __doc__="""List companies for which the client has ACL visibility.
  
  
  Attributes:
      parent:
          Required. Resource name of the tenant under which the company
          is created.  The format is
          "projects/{project\_id}/tenants/{tenant\_id}", for example,
          "projects/foo/tenant/bar".  If tenant id is unspecified, the
          default tenant will be used, for example, "projects/foo".
      page_token:
          The starting indicator from which to return results.
      page_size:
          The maximum number of companies to be returned, at most 100.
          Default is 100 if a non-positive number is provided.
      require_open_jobs:
          Set to true if the companies requested must have open jobs.
          Defaults to false.  If true, at most [page\_size][google.cloud
          .talent.v4beta1.ListCompaniesRequest.page\_size] of companies
          are fetched, among which only those with open jobs are
          returned.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.talent.v4beta1.ListCompaniesRequest)
    ),
)
_sym_db.RegisterMessage(ListCompaniesRequest)

ListCompaniesResponse = _reflection.GeneratedProtocolMessageType(
    "ListCompaniesResponse",
    (_message.Message,),
    dict(
        DESCRIPTOR=_LISTCOMPANIESRESPONSE,
        __module__="google.cloud.talent_v4beta1.proto.company_service_pb2",
        __doc__="""The List companies response object.
  
  
  Attributes:
      companies:
          Companies for the current client.
      next_page_token:
          A token to retrieve the next page of results.
      metadata:
          Additional information for the API invocation, such as the
          request tracking id.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.talent.v4beta1.ListCompaniesResponse)
    ),
)
_sym_db.RegisterMessage(ListCompaniesResponse)


DESCRIPTOR._options = None
_CREATECOMPANYREQUEST.fields_by_name["parent"]._options = None
_CREATECOMPANYREQUEST.fields_by_name["company"]._options = None
_GETCOMPANYREQUEST.fields_by_name["name"]._options = None
_UPDATECOMPANYREQUEST.fields_by_name["company"]._options = None
_DELETECOMPANYREQUEST.fields_by_name["name"]._options = None
_LISTCOMPANIESREQUEST.fields_by_name["parent"]._options = None

_COMPANYSERVICE = _descriptor.ServiceDescriptor(
    name="CompanyService",
    full_name="google.cloud.talent.v4beta1.CompanyService",
    file=DESCRIPTOR,
    index=0,
    serialized_options=_b(
        "\312A\023jobs.googleapis.com\322AShttps://www.googleapis.com/auth/cloud-platform,https://www.googleapis.com/auth/jobs"
    ),
    serialized_start=1108,
    serialized_end=2342,
    methods=[
        _descriptor.MethodDescriptor(
            name="CreateCompany",
            full_name="google.cloud.talent.v4beta1.CompanyService.CreateCompany",
            index=0,
            containing_service=None,
            input_type=_CREATECOMPANYREQUEST,
            output_type=google_dot_cloud_dot_talent__v4beta1_dot_proto_dot_company__pb2._COMPANY,
            serialized_options=_b(
                '\202\323\344\223\002b"0/v4beta1/{parent=projects/*/tenants/*}/companies:\001*Z+"&/v4beta1/{parent=projects/*}/companies:\001*\332A\016parent,company'
            ),
        ),
        _descriptor.MethodDescriptor(
            name="GetCompany",
            full_name="google.cloud.talent.v4beta1.CompanyService.GetCompany",
            index=1,
            containing_service=None,
            input_type=_GETCOMPANYREQUEST,
            output_type=google_dot_cloud_dot_talent__v4beta1_dot_proto_dot_company__pb2._COMPANY,
            serialized_options=_b(
                "\202\323\344\223\002\\\0220/v4beta1/{name=projects/*/tenants/*/companies/*}Z(\022&/v4beta1/{name=projects/*/companies/*}\332A\004name"
            ),
        ),
        _descriptor.MethodDescriptor(
            name="UpdateCompany",
            full_name="google.cloud.talent.v4beta1.CompanyService.UpdateCompany",
            index=2,
            containing_service=None,
            input_type=_UPDATECOMPANYREQUEST,
            output_type=google_dot_cloud_dot_talent__v4beta1_dot_proto_dot_company__pb2._COMPANY,
            serialized_options=_b(
                "\202\323\344\223\002r28/v4beta1/{company.name=projects/*/tenants/*/companies/*}:\001*Z32./v4beta1/{company.name=projects/*/companies/*}:\001*\332A\007company"
            ),
        ),
        _descriptor.MethodDescriptor(
            name="DeleteCompany",
            full_name="google.cloud.talent.v4beta1.CompanyService.DeleteCompany",
            index=3,
            containing_service=None,
            input_type=_DELETECOMPANYREQUEST,
            output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
            serialized_options=_b(
                "\202\323\344\223\002\\*0/v4beta1/{name=projects/*/tenants/*/companies/*}Z(*&/v4beta1/{name=projects/*/companies/*}\332A\004name"
            ),
        ),
        _descriptor.MethodDescriptor(
            name="ListCompanies",
            full_name="google.cloud.talent.v4beta1.CompanyService.ListCompanies",
            index=4,
            containing_service=None,
            input_type=_LISTCOMPANIESREQUEST,
            output_type=_LISTCOMPANIESRESPONSE,
            serialized_options=_b(
                "\202\323\344\223\002\\\0220/v4beta1/{parent=projects/*/tenants/*}/companiesZ(\022&/v4beta1/{parent=projects/*}/companies\332A\006parent"
            ),
        ),
    ],
)
_sym_db.RegisterServiceDescriptor(_COMPANYSERVICE)

DESCRIPTOR.services_by_name["CompanyService"] = _COMPANYSERVICE

# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
import grpc

from google.cloud.talent_v4beta1.proto import (
    event_pb2 as google_dot_cloud_dot_talent__v4beta1_dot_proto_dot_event__pb2,
)
from google.cloud.talent_v4beta1.proto import (
    event_service_pb2 as google_dot_cloud_dot_talent__v4beta1_dot_proto_dot_event__service__pb2,
)


class EventServiceStub(object):
    """A service handles client event report.
  """

    def __init__(self, channel):
        """Constructor.

    Args:
      channel: A grpc.Channel.
    """
        self.CreateClientEvent = channel.unary_unary(
            "/google.cloud.talent.v4beta1.EventService/CreateClientEvent",
            request_serializer=google_dot_cloud_dot_talent__v4beta1_dot_proto_dot_event__service__pb2.CreateClientEventRequest.SerializeToString,
            response_deserializer=google_dot_cloud_dot_talent__v4beta1_dot_proto_dot_event__pb2.ClientEvent.FromString,
        )


class EventServiceServicer(object):
    """A service handles client event report.
  """

    def CreateClientEvent(self, request, context):
        """Report events issued when end user interacts with customer's application
    that uses Cloud Talent Solution. You may inspect the created events in
    [self service
    tools](https://console.cloud.google.com/talent-solution/overview).
    [Learn
    more](https://cloud.google.com/talent-solution/docs/management-tools)
    about self service tools.
    """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")


def add_EventServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
        "CreateClientEvent": grpc.unary_unary_rpc_method_handler(
            servicer.CreateClientEvent,
            request_deserializer=google_dot_cloud_dot_talent__v4beta1_dot_proto_dot_event__service__pb2.CreateClientEventRequest.FromString,
            response_serializer=google_dot_cloud_dot_talent__v4beta1_dot_proto_dot_event__pb2.ClientEvent.SerializeToString,
        )
    }
    generic_handler = grpc.method_handlers_generic_handler(
        "google.cloud.talent.v4beta1.EventService", rpc_method_handlers
    )
    server.add_generic_rpc_handlers((generic_handler,))
